@@ -36,6 +36,9 @@ as.IFAgroup <- function(mxModel, data=NULL, container=NULL, ..., minItemsPerScor
   ret <- list(spec = expectation$ItemSpec,
               param = itemMat$values,
               free = itemMat$free,
+	      labels = itemMat$labels,
+	      # TODO maybe should include free variables in latent distribution?
+	      uniqueFree = length(unique(itemMat$labels[itemMat$free], incomparables=NA)),
               qpoints = expectation$qpoints,
               qwidth = expectation$qwidth)
   
@@ -94,9 +97,9 @@ as.IFAgroup <- function(mxModel, data=NULL, container=NULL, ..., minItemsPerScor
 	  }
   }
 
-  if (!missing(minItemsPerScore)) {
+  if (max(sapply(ret$spec, function(s) s$factors)) > 0 && !missing(minItemsPerScore)) {
     ret$minItemsPerScore <- minItemsPerScore
-    ret$score <- EAPscores(ret)
+    ret$score <- EAPscores(ret, compressed=TRUE)
   }
 
   ret
@@ -104,9 +107,12 @@ as.IFAgroup <- function(mxModel, data=NULL, container=NULL, ..., minItemsPerScor
 
 #' Strip data and scores from an IFA group
 #'
+#' In addition, the weightColumn is reset to NULL.
+#' 
 #' @param grp an IFA group
 stripData <- function(grp) {
 	grp$data <- NULL
 	grp$score <- NULL
+	grp$weightColumn <- NULL
 	grp
 }
